<?php
class SendmsgConsumer
{
	private static $Token = null;
	private static $SiteID = null;
	private static $ApiPassword = null;
	private $apiResource = null;
	private const smUrl_Base = null;

	public function __construct($siteID=null, $apiPassword=null)
	{
		
		self::$SiteID=empty(self::$SiteID)?$siteID:self::$SiteID;
		self::$ApiPassword=$apiPassword;
		$this->apiResource = curl_init();
		$this->smUrl_Base = 'http://gconvertrest.sendmsg.co.il/api/Sendmsg/';
	}

	private function CheckToken(): bool
	{
		curl_setopt_array($this->apiResource, array(
			CURLOPT_URL => $this->smUrl_Base . 'test',
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_HEADER => false,
			CURLOPT_POST => true,
			CURLOPT_HTTPHEADER => array(
				sprintf("Authorization: %s", self::$Token),
				sprintf("content-length: %s", 0)
			)
		));

		$response = curl_exec($this->apiResource);

		return $this->_HandleResponse($response, function ($el) {

			if (is_array($el) && in_array('Message', $el))
				return true;

			return false;
		});
	}

	private function RefreshToken()
	{
		if(self::$Token==null || $this->CheckToken())
			self::$Token=$this->CreateToken();
	}


	private function CreateToken()
	{
		//The JSON data.
		$jsonData = array(
			'siteID' => self::$SiteID,
			'password' => self::$ApiPassword
		);

		//Encode the array into JSON.
		$jsonDataEncoded = json_encode($jsonData);


		curl_setopt_array($this->apiResource, array(
			CURLOPT_URL => $this->smUrl_Base . 'token',
			CURLOPT_POST => true,
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_HEADER => false,
			CURLOPT_POSTFIELDS => $jsonDataEncoded,
			CURLOPT_HTTPHEADER => array(
				"Content-Type: application/json",
				sprintf("content-length: %s", strlen($jsonDataEncoded)),
				)

		));


		$response = curl_exec($this->apiResource);

		return $this->_HandleResponse($response, function ($el) {
			return $el['Token'];
		});
	}

	public function sendmsg_get_fields_keys()
	{

		$this->RefreshToken();

		curl_setopt_array($this->apiResource, array(
			CURLOPT_URL => $this->smUrl_Base . 'GetAllFields',
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_HEADER => false,
			CURLOPT_POST => true,
			CURLOPT_HTTPHEADER => array(
				"Accept: application/json",
				sprintf("content-length: %s", 0),
				sprintf("Authorization: %s", self::$Token)
			)
		));

		$response = curl_exec($this->apiResource);


		return $this->_HandleResponse($response, function ($el) {
			$fields_data = array_slice($el['AllFields'], 2);
			array_unshift($fields_data, 'Cellphone');

			return $fields_data;
		});
	}

	public function sendmsg_get_lists()
	{

		$this->RefreshToken();

		curl_setopt_array($this->apiResource, array(
			CURLOPT_URL => $this->smUrl_Base . 'GetMailingListNames',
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_HEADER => false,
			CURLOPT_POST => true,
			CURLOPT_HTTPHEADER => array(
				"Accept: application/json",
				sprintf("content-length: %s", 0),
				sprintf("Authorization: %s", self::$Token)
			)
		));

		$response = curl_exec($this->apiResource);


		return $this->_HandleResponse($response, function ($el) {

			$OutputArray = array_map(function ($map) {
				return array('id' => $map['ExistingListID'], 'name' => $map['NewListName']);
			}, $el['listNames']);

			return $OutputArray;
		});
	}

	public function sendmsg_create_new_list($list_name)
	{

		$this->RefreshToken();

		$jsonData = array(

			'IsNewList' => true,
			'NewListName' => $list_name,
			'NewListDescription' => 'קבוצה זו נוצרה באמצעות פלאגין שלח-מסר של וורדפרס'

		);

		//Encode the array into JSON.
		$jsonDataEncoded = json_encode($jsonData, JSON_UNESCAPED_UNICODE);


		curl_setopt_array($this->apiResource, array(
			CURLOPT_URL => $this->smUrl_Base . 'CreateMalingList',
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_HEADER => false,
			CURLOPT_POST => true,
			CURLOPT_POSTFIELDS => $jsonDataEncoded,
			CURLOPT_HTTPHEADER => array(
				"Content-Type: application/json",
				sprintf("Authorization: %s", self::$Token),
				sprintf("content-length: %s", strlen($jsonDataEncoded)),
			)
		));

		$response = curl_exec($this->apiResource);

		return $this->_HandleResponse($response);
	}

	private function _HandleResponse($ValidResponse, $Hendler = null)
	{
		if ($ValidResponse)
			if ($Hendler == null)
				return json_decode($ValidResponse);
			else
				return $Hendler(json_decode($ValidResponse, true));
		else
			throw new Exception("Error Processing Request " . curl_error($this->apiResource), 1);
	}

	function sendmsg_add_user_to_lists($user_data,$lists)
	{

		$this->RefreshToken();
		//moving custom fields to UserSystemFields array
		$UserSystemFields['UserSystemFields'] = array();
	   
		foreach($user_data as $key => $val)
		{
			if ($key == 'EmailAddress' || $key == 'Cellphone')
			   $UserSystemFields[$key] = $val;
			else
			  array_push($UserSystemFields['UserSystemFields'], array('Key'=>$key,'Value' => $val));
		}


		$jsonData = array(

			'Users' => array($UserSystemFields),
			'MailingLists' => array_map(function ($el)
			{
				return array('ExistingListID'=>$el);
			}
			,$lists)
			
		);

		$jsonDataEncoded = json_encode($jsonData, JSON_UNESCAPED_UNICODE);

		curl_setopt_array($this->apiResource, array(
			CURLOPT_URL => $this->smUrl_Base . 'AddUsersToLists',
			CURLOPT_RETURNTRANSFER => true,
			CURLOPT_HEADER => false,
			CURLOPT_POST => true,
			CURLOPT_POSTFIELDS => $jsonDataEncoded,
			CURLOPT_HTTPHEADER => array(
				"Content-Type: application/json",
				sprintf("content-length: %s", strlen($jsonDataEncoded)),
				sprintf("Authorization: %s", self::$Token)
			)
		));

		$response = curl_exec($this->apiResource);

		return $this->_HandleResponse($response);

	}


	function __destruct()
	{
		curl_close($this->apiResource);
	}
}



function testEnv()
{
	$test = new SendmsgConsumer("25609", "dbtk");
	echo var_dump($test->sendmsg_get_fields_keys());
	echo var_dump($test->sendmsg_get_lists());

	$check2=$test->sendmsg_add_user_to_lists(array('EmailAddress'=>'testwordpress@dsdsds.com'),array("188406"));
	echo var_dump($check2);
	//echo var_dump($test->sendmsg_create_new_list("testwordpressPlugin"));
	
}
















// function prepare_MailingLists_array($l)
// {
// 	return array(
// 		'ExistingListID' => $l, // specify a list id that already exists in the system. optional
// 		'ExistingListIDSpecified' => true, // must be true when setting ExistingListID
// 	);
// }
// function sendmsg_get_fields_keys()
// {
// 	$sendMsgService = new SoapClient(SENDMSG_API_URL);
// 	$Login = array(
// 		'SiteID' => get_option('sendmsg_api_opts')['user_id'],
// 		'ApiPassword' => get_option('sendmsg_api_opts')['api_key']
// 	);
// 	$response = $sendMsgService->GetAllFields($Login);
// 	$fields_data = array_slice($response->AllFields, 2);
// 	$fields_keys = array_map(function ($f) {
// 		return $f->Value;
// 	}, $fields_data);
// 	return $fields_keys;
// }

// function sendmsg_get_lists()
// {
// 	$sendMsgService = new SoapClient(SENDMSG_API_URL);
// 	$Login = array(
// 		'SiteID' => get_option('sendmsg_api_opts')['user_id'],
// 		'ApiPassword' => get_option('sendmsg_api_opts')['api_key']
// 	);
// 	$response = $sendMsgService->GetMailingListNames($Login);
// 	$lists_res = $response->listNames->SendMsgList;
// 	$lists = array();
// 	foreach ($lists_res as $l) {
// 		array_push($lists, array('id' => $l->ExistingListID, 'name' => $l->NewListName));
// 	}
// 	return $lists;
// }
// function sendmsg_create_new_list($list_name)
// {
// 	//moving custom fields to UserSystemFields array
// 	$sendMsgService = new SoapClient(SENDMSG_API_URL);
// 	$Login = array(
// 		'SiteID' => get_option('sendmsg_api_opts')['user_id'],
// 		'ApiPassword' => get_option('sendmsg_api_opts')['api_key']
// 	);
// 	$AddUsersToLists = $Login + array(
// 		'MailingLists' => array(
// 			array(
// 				'IsNewList' => true, // create a new list in the system?
// 				'IsNewListSpecified' => true, // must be true when setting IsNewList
// 				'NewListName' => $list_name,
// 				'NewListDescription' => 'קבוצת דיוור המרכזת משתמשים חדשים שנרשמו לאתר הוורדפרס',
// 			)
// 		)
// 	);
// 	$sendMsgService->AddUsersToLists($AddUsersToLists);
// }
// function sendmsg_add_user_to_lists($user_data, $lists)
// {
// 	//moving custom fields to UserSystemFields array
// 	$user_data_with_UserSystemFields['UserSystemFields'] = array();
// 	foreach ($user_data as $k => $v) {
// 		if ($k == 'EmailAddress' || $k == 'Cellphone') {
// 			$user_data_with_UserSystemFields[$k] = $v;
// 		} else  array_push($user_data_with_UserSystemFields['UserSystemFields'], array('Key' => $k, 'Value' => $v));
// 	}

// 	$sendMsgService = new SoapClient(SENDMSG_API_URL);
// 	$Login = array(
// 		'SiteID' => get_option('sendmsg_api_opts')['user_id'],
// 		'ApiPassword' => get_option('sendmsg_api_opts')['api_key']
// 	);
// 	$AddUsersToLists = $Login + array(
// 		'Users' => array(
// 			$user_data_with_UserSystemFields
// 		),
// 		'MailingLists' => array_map('prepare_MailingLists_array', $lists)
// 	);
// 	return $sendMsgService->AddUsersToLists($AddUsersToLists);
// }
