<?php
/*
Plugin Name: שלח מסר
Description: איסוף פרטי הגולשים ושליחתם למערכת שלח מסר
Version:     0.0.3
Author:      Aviz
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/

defined('ABSPATH') or die();

define('SENDMSG_PLUGIN_DIR', plugins_url('/', __FILE__));


require_once(__DIR__ . '/includes/defines.php');
require_once(__DIR__ . '/includes/utils.php');
require_once(__DIR__ . '/includes/sendmsg-api.php');
require_once(__DIR__ . '/includes/sm_admin.php');




// SECONDARY FUNCTIONS
function array_clean_empty_values($arr)
{
    return array_filter($arr, function ($value) {
        return ($value != '' && $value != NULL);
    });
}
function transform_data($data, $transform_matrix)
{
    $transformed_data = array();
    foreach ($transform_matrix as $key => $value) {
        if (isset($data[$key])) $transformed_data[$value] = $data[$key];
    }
    return $transformed_data;
}
function prepare_transform_matrix($arr)
{
    $prepared_transform_matrix = array();
    foreach ($arr as $i) {
        $prepared_transform_matrix[$i[0]] = $i[1];
    }
    return $prepared_transform_matrix;
}
function sendmsg_filter_and_transform($data_raw, $slug)
{
    if (strpos($slug, 'woocommerce_item') === 0) {
        $include_keys  =     array_merge(get_option('sendmsg_woocommerce_item_data_include_defaults'), get_option('sendmsg_woocommerce_item_data_include'));

        $data_before_clean = $data_raw;
        $data = array_clean_empty_values($data_before_clean);
        // prepare transform_matrix
        $transform_matrix_defaults = get_option('sendmsg_woocommerce_item_transform_matrix_defaults', array('user_email' => 'EmailAddress'));
        $transform_matrix_raw = get_post_meta(substr($slug, 17), 'transform_matrix_raw', true);
        $transform_matrix_prepared =  prepare_transform_matrix($transform_matrix_raw);
        $transform_matrix = array_merge($transform_matrix_defaults, $transform_matrix_prepared);
        $transformed_data = transform_data($data, $transform_matrix);
        return $transformed_data;
    }

    $include_keys  = array_merge(get_option('sendmsg_' . $slug . '_data_include_defaults'), get_option('sendmsg_' . $slug . '_data_include'));

    $data_before_clean = $data_raw;
    $data = array_clean_empty_values($data_before_clean);

    // prepare transform_matrix
    $transform_matrix_defaults = get_option('sendmsg_' . $slug . '_transform_matrix_defaults', array('user_email' => 'EmailAddress'));
    $transform_matrix_raw = get_option('sendmsg_' . $slug . '_transform_matrix_raw');
    $transform_matrix_prepared =  prepare_transform_matrix($transform_matrix_raw);
    $transform_matrix = array_merge($transform_matrix_defaults, $transform_matrix_prepared);
    $transformed_data = transform_data($data, $transform_matrix);
    return $transformed_data;
}
function sendmsg_woocommerce_prepare_data($order_id)
{

    $order = wc_get_order($order_id);
    $order_data_raw = $order->get_data(); // The Order data    
    $data_all = flatten(objectToArray($order_data_raw));
    $data_all['user_email'] = $data_all['billing.email'];
    $data = sendmsg_filter_and_transform($data_all, 'woocommerce');
    return  $data;
}

//
function sendmsg_woocommerce_item_prepare_data($item_id, $order)
{
    $order_data['_order'] = $order->get_data();
    $user_id = $order->get_user_id();
    $item = wc_get_product($item_id);
    $item_data_raw = $item->get_data();
    $data_all = flatten(array_merge($order_data, $item_data_raw));
    $data_all['user_email'] = get_userdata($user_id)->user_email;
    $data = sendmsg_filter_and_transform($data_all, 'woocommerce_item_' . $item_id);
    return  $data;
}
function sendmsg_user_register_prepare_data($user_id)
{

    $user_core_data = objectToArray(get_userdata($user_id)->data);
    $user_meta_data_raw = get_metadata('user', $user_id);
    $user_meta_data = array();

    foreach ($user_meta_data_raw as $key => $value) {
        $user_meta_data[$key] = $value[0];
    }

    $user_data = array_merge($user_core_data, $user_meta_data);
    $data_all = $user_data;
    $data = sendmsg_filter_and_transform($data_all, 'user_register');
    return  $data;
}

function sendmsg_user_register_ap_id_prepare_data($user_id)
{
    $data_all = array('ap_id' => $_COOKIE['ap_id'], 'user_email' => get_userdata($user_id)->user_email);
    $data = sendmsg_filter_and_transform($data_all, 'user_register_ap_id');
    return  $data;
}
function sendmsg_woocommerce_ap_id_prepare_data($order_id)
{
    $order = wc_get_order($order_id);
    $data_all = array('ap_id' => $_COOKIE['ap_id'], 'user_email' => flatten(objectToArray($order->get_data()))['billing.email']);
    $data = sendmsg_filter_and_transform($data_all, 'woocommerce_ap_id');
    return  $data;
}


function sendmsg_user_register($user_id)
{
    $data = sendmsg_user_register_prepare_data($user_id);
    $lists = get_option('sendmsg_user_register_defaults_lists');
    return getConsumer()->sendmsg_add_user_to_lists($data, $lists);
}


function sendmsg_woocommerce_SendUserDataToSM($order_id)
{
    $data = sendmsg_woocommerce_prepare_data($order_id);
    $lists = get_option('sendmsg_woocommerce_defaults_lists');
    $results = array('order' => getConsumer()->sendmsg_add_user_to_lists($data, $lists));
    // Get an instance of the WC_Order object


    // Iterating through each WC_Order_Item_Product objects
    // foreach ($order->get_items() as $item_key => $item_values){
    // 	$item_id = $item_values->get_data()['product_id'];
    //     $data = sendmsg_woocommerce_item_prepare_data($item_id, $order);
    // 	$lists = get_post_meta($item_id,'sendmsg_woocommerce_item_defaults_lists',true);
    // 	$results[$item_id] = getConsumer()->sendmsg_add_user_to_lists($data, $lists);
    // }

    return $results;
}

function sendmsg_woocommerce_ItemUserToSMML($order)
{
    foreach ($order->get_items() as $item_key => $item_values) {
        $item_id = $item_values->get_data()['product_id'];
        $data = sendmsg_woocommerce_item_prepare_data($item_id, $order);
        $lists = get_post_meta($item_id, 'sendmsg_woocommerce_item_defaults_lists', true);
        $result = getConsumer()->sendmsg_add_user_to_lists($data, $lists);
    }
    return $result;
}

function sendmsg_woocommerce_ap_id($order_id)
{
    if (!isset($_COOKIE['ap_id'])) return false;
    $data = sendmsg_woocommerce_ap_id_prepare_data($order_id);
    $lists = get_option('sendmsg_woocommerce_ap_id_defaults_lists');
    return getConsumer()->sendmsg_add_user_to_lists($data, $lists);
}


function sendmsg_user_register_ap_id($user_id)
{
    if (!isset($_COOKIE['ap_id'])) return false;
    $data = sendmsg_user_register_ap_id_prepare_data($user_id);
    $lists = get_option('sendmsg_user_register_ap_id_defaults_lists');
    return getConsumer()->sendmsg_add_user_to_lists($data, $lists);
}

//function
// TESTS

function create_dummy_data()
{
    //  update_option('sendmsg_api_opts',array('user_id'=>'25609','api_key'=>'dbtk'));
    update_option('sendmsg_user_register_data_include_defaults', array('user_email', 'display_name'));
    update_option('sendmsg_user_register_transform_matrix_defaults', array('user_email' => 'EmailAddress', 'display_name' => 'שם'));
    update_option('sendmsg_user_register_data_include', array('description', 'user_login'));
    update_option('sendmsg_user_register_transform_matrix_raw', array(array('user_login', 'שם משתמש'), array('description', 'תיאור')));
    //  update_option('sendmsg_user_register_defaults_lists',array(165123,122004));
    return 'dummy data created';
}



// MAIN action
// user_register
add_action('user_register', 'sendmsg_user_register');
add_action('profile_update', 'sendmsg_user_register');
// woocommerce SMML send msg mailing List
add_action('woocommerce_new_order', 'sendmsg_woocommerce_SendUserDataToSM');
//SMML= send msg mailing List
add_action('woocommerce_email_before_order_table', 'sendmsg_woocommerce_ItemUserToSMML');

// affiliate program
if (isset($_COOKIE['ap_id'])) {
    add_action('user_register', 'sendmsg_user_register_ap_id');
    add_action('woocommerce_new_order', 'sendmsg_woocommerce_ap_id');
}//debug action
//add_action('admin_init','testEnv');
